@@ -80,24 +80,22 @@ static void exit_all (void)
 /*------------------------------------------------------------------*/
 static void disp_base_message (void)
 {
- log_println_str("Liquid War 5.3.1 by U-Foot.");
- log_println_str("This version released on April 9th 2000.");
+ log_println_str("Liquid War 5.3.2 by U-Foot.");
+ log_println_str("This version released on June 19th 2000.");
  log_println();
- log_println_str("E-mail    : ufoot@bigfoot.com");
- log_println_str("Web sites : www.geocities.com/ufoot/");
- log_println_str("            ufoot.free.fr/");
- log_println_str("            www.multimania.com/ufoot/");
+ log_println_str("E-mail    : ufoot@ufoot.org");
+ log_println_str("Web       : http://www.ufoot.org/liquidwar/");
  log_println_str("Address   : Christian Mauduit");
  log_println_str("            8 Allee de la Fresnaie");
  log_println_str("            95120 Ermont FRANCE");
  log_println();
  log_println_str("This game is FREE SOFTWARE, protected by the GPL (www.fsf.org).");
  log_println_str("You can use it, copy it, distribute it and modify it.");
- log_println_str("The source code is available on my web sites.");
+ log_println_str("The source code is available on my web site.");
  log_println_str("Liquid War should stay free software for ever.");
  log_println_str("I am NOT responsible for any damage caused by this software.");
  log_println();
- log_println_str("Check out my web sites for complete information.");
+ log_println_str("Check out http://www.ufoot.org for complete information.");
 }
 
 /*------------------------------------------------------------------*/
