@@ -35,6 +35,8 @@
 /*==================================================================*/
 
 #include <allegro.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "parser.h"
 #include "startup.h"
@@ -231,10 +233,24 @@ static void correct_path (char *path)
 /*------------------------------------------------------------------*/
 static void set_path (void)
 {
+ char home_path[512];
+ char *home_env;
+
  if (exist_argument_value (IDENT_CFG))
      strcpy(STARTUP_CFG_PATH,get_argument_str (IDENT_CFG));
  else
-     strcpy(STARTUP_CFG_PATH,DEFAULT_CFG_PATH);
+    {
+    #ifdef ALLEGRO_UNIX
+         home_env=getenv("HOME"); 
+         strcpy(home_path,home_env);
+         strcat(home_path,"/");
+    #else
+         home_env="";
+         strcpy(home_path,home_env);
+    #endif
+     strcpy(STARTUP_CFG_PATH,home_path);
+     strcat(STARTUP_CFG_PATH,DEFAULT_CFG_PATH);
+    }
 
  if (exist_argument_value (IDENT_DAT))
      strcpy(STARTUP_DAT_PATH,get_argument_str (IDENT_DAT));
